Command-line Scripts
====================

Astroimtools installs a couple of useful utility programs for calculating
image statistics and simple arithmetic.

imarith
-------
.. automodule:: astroimtools.scripts.imarith

imstats
-------
.. automodule:: astroimtools.scripts.imstats
